@@ -11,16 +11,21 @@
  */
 #ifndef ZYPP_APICONFIG_H
 #define ZYPP_APICONFIG_H
+#define APIConfig(VAR) VAR
 
-#define LIBZYPP_VERSION_STRING "17.36.6"
+#define LIBZYPP_VERSION_STRING "17.37.14"
 #define LIBZYPP_VERSION_MAJOR  17
-#define LIBZYPP_VERSION_MINOR  36
-#define LIBZYPP_VERSION_PATCH  6
+#define LIBZYPP_VERSION_MINOR  37
+#define LIBZYPP_VERSION_PATCH  14
 #define LIBZYPP_SOVERSION      1735
-#define LIBZYPP_VERSION        173606
+#define LIBZYPP_VERSION        173714
 
-#define LIBZYPP_CODESTREAM     "default"
+#define LIBZYPP_CODESTREAM     ""
 
+// Legacy default behavior which might be enabled for legacy codestreams
 #define LIBZYPP_CONFIG_USE_DELTARPM_BY_DEFAULT 0
+#define LIBZYPP_CONFIG_USE_CLASSIC_RPMTRANS_BY_DEFAULT 0
+#define LIBZYPP_CONFIG_USE_LEGACY_CURL_BACKEND_BY_DEFAULT 0
+#define LIBZYPP_CONFIG_USE_SERIAL_PACKAGE_DOWNLOAD_BY_DEFAULT 0
 
 #endif //ZYPP_APICONFIG_H
